import { newBucket } from './bucket.js';
import { getS3Driver } from './driver-aws.js';
import { getGsDriver } from './driver-gcp.js';
import { getMinioDriver } from './driver-minio.js';
export { signUrl, urlSigner } from './url-signer.js';
export async function getBucket(options) {
    if (options == null) {
        throw new Error(`ERROR - cloud-bucket - Cannot getBucket with options ${options}`);
    }
    const log = options.log ?? false; // by default, false. 
    // if has .project_id, assume GcpBucket
    const driver = await getDriver(options);
    const bucket = newBucket({ driver, log });
    return bucket;
}
async function getDriver(driverCfg) {
    if (isGsDriverCfg(driverCfg)) {
        return getGsDriver(driverCfg);
    }
    else if (isMinioDriverCfg(driverCfg)) { // IMPORTANT MUST be before S3Driver, because same access_key... 
        return getMinioDriver(driverCfg);
    }
    else if (isS3DriverCfg(driverCfg)) {
        return getS3Driver(driverCfg);
    }
    else {
        throw new Error(`bucket config does not seem to be valid (only support Gcp and Aws for now)`);
    }
}
function isGsDriverCfg(opts) {
    return opts.hasOwnProperty('project_id');
}
function isS3DriverCfg(opts) {
    return opts.hasOwnProperty('access_key_id');
}
function isMinioDriverCfg(opts) {
    return opts.hasOwnProperty('minio_endpoint') && opts.minio_endpoint != null;
}
